@@ -143,7 +143,7 @@ char *hci_bustostr(int bus)
 {
 	switch (bus) {
 	case HCI_VIRTUAL:
-		return "VIRTUAL";
+		return "Virtual";
 	case HCI_USB:
 		return "USB";
 	case HCI_PCCARD:
@@ -161,7 +161,7 @@ char *hci_bustostr(int bus)
 	case HCI_I2C:
 		return "I2C";
 	default:
-		return "UNKNOWN";
+		return "Unknown";
 	}
 }
 
@@ -173,12 +173,12 @@ char *hci_dtypetostr(int type)
 char *hci_typetostr(int type)
 {
 	switch (type) {
-	case HCI_BREDR:
-		return "BR/EDR";
+	case HCI_PRIMARY:
+		return "Primary";
 	case HCI_AMP:
 		return "AMP";
 	default:
-		return "UNKNOWN";
+		return "Unknown";
 	}
 }
 
